@@ -367,4 +367,16 @@ class APIClient(object):
             raise SlideScoreErrorException("Failed reimporting: " + rjson["log"]);
         return { "id": rjson['id'], "log": rjson["log"]}
         
-  
+    def get_slide_path(self, image_id):
+        response = self.perform_request("GetSlidePath", {"imageId": image_id}, method="GET")
+        rjson = response.json()
+        if not rjson["success"]:
+            raise SlideScoreErrorException("Failed getting slide path: " + response.text);
+        return rjson['path'] 
+        
+
+    def update_slide_path(self, image_id, new_path):
+        response = self.perform_request("UpdateSlidePath", {"imageId": image_id, "newPath": new_path}, method="POST")
+        rjson = response.json()
+        if not rjson["success"]:
+            raise SlideScoreErrorException("Failed updating slide path: " + response.text);
